EventCode

Struct EventCode 

pub struct EventCode(/* private fields */);
Contains the event code read as a 32-bit unsigned big-endian integer.

Implementations

Source

impl EventCode

pub fn value(&self) -> u32

Returns the complete event code.

pub fn main(&self) -> u32

Returns the event class, can be used to filter events.

pub fn sub(&self) -> u32

Returns the event subclass, can also be used to filter events.

pub fn minor(&self) -> u32

Returns the event minor, identifies the event in its class and subclass.